@@ -1,9 +1,11 @@
 import copy
 import inspect
 import logging
+import logging.config
 import logging.handlers
 import os
 import shutil
+import tempfile
 import warnings
 from pathlib import Path
 from types import TracebackType
@@ -33,7 +35,6 @@ from rasa.constants import (
     ENV_LOG_LEVEL_KAFKA,
 )
 from rasa.shared.constants import DEFAULT_LOG_LEVEL, ENV_LOG_LEVEL, TCP_PROTOCOL
-from rasa.shared.exceptions import RasaException
 import rasa.shared.utils.io
 
 logger = logging.getLogger(__name__)
@@ -70,9 +71,18 @@ EXPECTED_WARNINGS: List[Tuple[Type[Warning], str]] = [
     # Cannot fix this deprecation warning since we need to support two
     # numpy versions as long as we keep python 37 around
     (DeprecationWarning, "the `interpolation=` argument to quantile was renamed"),
+    # the next two warnings are triggered by adding 3.10 support,
+    # for more info: https://docs.python.org/3.10/whatsnew/3.10.html#deprecated
+    (DeprecationWarning, "the load_module*"),
+    (ImportWarning, "_SixMetaPathImporter.find_spec*"),
+    # 3.10 specific warning: https://github.com/pytest-dev/pytest-asyncio/issues/212
+    (DeprecationWarning, "There is no current event loop"),
 ]
 
 EXPECTED_WARNINGS.extend(EXPECTED_PILLOW_DEPRECATION_WARNINGS)
+PYTHON_LOGGING_SCHEMA_DOCS = (
+    "https://docs.python.org/3/library/logging.config.html#dictionary-schema-details"
+)
 
 
 class TempDirectoryPath(str, ContextManager):
@@ -94,6 +104,21 @@ class TempDirectoryPath(str, ContextManager):
             shutil.rmtree(self)
 
 
+def get_temp_dir_name() -> Text:
+    """Returns the path name of a newly created temporary directory."""
+    tempdir_name = tempfile.mkdtemp()
+
+    return decode_bytes(tempdir_name)
+
+
+def decode_bytes(name: Union[Text, bytes]) -> Text:
+    """Converts bytes object to string."""
+    if isinstance(name, bytes):
+        name = name.decode("UTF-8")
+
+    return name
+
+
 def read_global_config(path: Text) -> Dict[Text, Any]:
     """Read global Rasa configuration.
 
@@ -110,8 +135,30 @@ def read_global_config(path: Text) -> Dict[Text, Any]:
         return {}
 
 
+def configure_logging_from_file(logging_config_file: Text) -> None:
+    """Parses YAML file content to configure logging.
+
+    Args:
+        logging_config_file: YAML file containing logging configuration to handle
+            custom formatting
+    """
+    logging_config_dict = rasa.shared.utils.io.read_yaml_file(logging_config_file)
+
+    try:
+        logging.config.dictConfig(logging_config_dict)
+    except (ValueError, TypeError, AttributeError, ImportError) as e:
+        logging.debug(
+            f"The logging config file {logging_config_file} could not "
+            f"be applied because it failed validation against "
+            f"the built-in Python logging schema. "
+            f"More info at {PYTHON_LOGGING_SCHEMA_DOCS}.",
+            exc_info=e,
+        )
+
+
 def configure_logging_and_warnings(
     log_level: Optional[int] = None,
+    logging_config_file: Optional[Text] = None,
     warn_only_once: bool = True,
     filter_repeated_logs: bool = True,
 ) -> None:
@@ -121,11 +168,16 @@ def configure_logging_and_warnings(
         log_level: The log level to be used for the 'Rasa' logger. Pass `None` to use
             either the environment variable 'LOG_LEVEL' if it is specified, or the
             default log level otherwise.
+        logging_config_file: YAML file containing logging configuration to handle
+            custom formatting
         warn_only_once: determines whether user warnings should be filtered by the
             `warnings` module to appear only "once"
         filter_repeated_logs: determines whether `RepeatedLogFilter`s are added to
             the handlers of the root logger
     """
+    if logging_config_file is not None:
+        configure_logging_from_file(logging_config_file)
+
     if log_level is None:  # Log level NOTSET is 0 so we use `is None` here
         log_level_name = os.environ.get(ENV_LOG_LEVEL, DEFAULT_LOG_LEVEL)
         # Change log level from str to int (note that log_level in function parameter
@@ -513,29 +565,3 @@ def find_unavailable_packages(package_names: List[Text]) -> Set[Text]:
 def module_path_from_class(clazz: Type) -> Text:
     """Return the module path of an instance's class."""
     return clazz.__module__ + "." + clazz.__name__
-
-
-def get_bool_env_variable(variable_name: str, default_variable_value: bool) -> bool:
-    """Fetch bool value stored in environment variable.
-
-    If environment variable is set but value is
-    not of boolean nature, an exception will be raised.
-
-    Args: variable_name:
-        Name of the environment variable.
-        default_variable_value: Value to be returned if environment variable is not set.
-
-    Returns:
-        A boolean value stored in the environment variable
-        or default value if environment variable is not set.
-    """
-    true_values = (str(True).lower(), str(1).lower())
-    false_values = (str(False).lower(), str(0).lower())
-    value = os.getenv(variable_name, default=str(default_variable_value))
-
-    if value.lower() not in true_values + false_values:
-        raise RasaException(
-            f"Invalid value `{value}` for variable `{variable_name}`. "
-            f"Available values are `{true_values + false_values}`"
-        )
-    return value.lower() in true_values
