@@ -132,14 +132,13 @@ class EndpointConfig:
         method: Text = "post",
         subpath: Optional[Text] = None,
         content_type: Optional[Text] = "application/json",
-        compress: bool = False,
         **kwargs: Any,
     ) -> Optional[Any]:
         """Send a HTTP request to the endpoint. Return json response, if available.
 
         All additional arguments will get passed through
-        to aiohttp's `session.request`.
-        """
+        to aiohttp's `session.request`."""
+
         # create the appropriate headers
         headers = {}
         if content_type:
@@ -167,7 +166,6 @@ class EndpointConfig:
                 url,
                 headers=headers,
                 params=self.combine_parameters(kwargs),
-                compress=compress,
                 ssl=sslcontext,
                 **kwargs,
             ) as response:
